module.exports = defineTest({
	description: 'does not deconflict due to tree-shaken global variables'
});
